@@ -596,5 +596,10 @@ CausalShrinkageForest <- function(y,
     
   }
   
+  # remove burn-in of sigma
+  if (!sigma_known) {
+    fit$sigma <- fit$sigma[-(1:N_burn)]
+  } 
+
   return(fit)
 }
